@@ -2,7 +2,7 @@ package Test2::Harness::TestFile;
 use strict;
 use warnings;
 
-our $VERSION = '1.000152';
+our $VERSION = '1.000154';
 
 use Carp qw/croak/;
 
@@ -385,12 +385,13 @@ sub _parse_shbang {
     }xi;
 
     if ($line =~ $shbang_re) {
-        my @switches = grep { m/\S/ } split /\s+/, $1 if defined $1;
+        my @switches;
+        @switches         = grep { m/\S/ } split /\s+/, $1 if defined $1;
         $shbang{switches} = \@switches;
         $shbang{line}     = $line;
     }
     elsif ($line =~ m/^#!/ && $line !~ m/perl/i) {
-        $shbang{line} = $line;
+        $shbang{line}     = $line;
         $shbang{non_perl} = 1;
     }
 
